package net.knarcraft.permissionsigns.container;

import org.bukkit.entity.Player;

/**
 * A sign creation request represents the state where a player has used the create command, but not clicked a sign
 */
public class SignCreationRequest implements Comparable<SignCreationRequest> {

    private final PermissionSign permissionSign;
    private final Player player;
    private final long initiationTime;

    /**
     * Instantiates a new sign creation request
     *
     * @param permissionSign <p>The sign which is about to be created</p>
     * @param player         <p>The player starting to create the permission sign</p>
     * @param initiationTime <p>The time the request was initiated</p>
     */
    public SignCreationRequest(PermissionSign permissionSign, Player player, long initiationTime) {
        this.permissionSign = permissionSign;
        this.player = player;
        this.initiationTime = initiationTime;
    }

    /**
     * Gets the permission sign involved in this request
     *
     * @return <p>The involved permission sign</p>
     */
    public PermissionSign getPermissionSign() {
        return this.permissionSign;
    }

    /**
     * Gets the player involved in this request
     *
     * @return <p>The involved player</p>
     */
    public Player getPlayer() {
        return this.player;
    }

    /**
     * Gets the time this sign creation request was initiated
     *
     * @return <p>The time this request was initiated</p>
     */
    public long initiationTime() {
        return this.initiationTime;
    }

    @Override
    public boolean equals(Object other) {
        if (!(other instanceof SignCreationRequest otherRequest)) {
            return false;
        }
        if (this == other) {
            return true;
        }

        return this.getPlayer().getUniqueId() == otherRequest.getPlayer().getUniqueId();
    }

    @Override
    public int compareTo(SignCreationRequest other) {
        return (int) (this.initiationTime - other.initiationTime);
    }
}
