package net.knarcraft.permissionsigns.thread;

import net.knarcraft.permissionsigns.container.TemporaryPermission;
import net.knarcraft.permissionsigns.manager.PermissionManager;

import java.util.Queue;

/**
 * The permission timeout thread is responsible for removing temporary permissions as they expire
 */
public class PermissionTimeoutThread implements Runnable {

    @Override
    public void run() {
        long currentTime = System.currentTimeMillis();
        Queue<TemporaryPermission> temporaryPermissions = PermissionManager.getTemporaryPermissions();
        TemporaryPermission topPermission = temporaryPermissions.peek();

        if (topPermission == null) {
            return;
        }

        while (currentTime > topPermission.getGrantedTime() + (1000L * topPermission.getGrantedDuration())) {
            temporaryPermissions.poll();
            PermissionManager.removeTemporaryPermission(topPermission.getGrantedPlayer(), topPermission.getPermissionNode());

            topPermission = temporaryPermissions.peek();
            if (topPermission == null) {
                return;
            }
        }
    }

}
