package net.knarcraft.permissionsigns.thread;

import net.knarcraft.permissionsigns.container.SignCreationRequest;

import java.util.Queue;

/**
 * The sign creation request timeout thread is responsible for removing sign creation requests as they time out
 */
public class SignCreationRequestTimeoutThread implements Runnable {

    private final Queue<SignCreationRequest> signCreationRequests;

    /**
     * Instantiates a new sign creation request timeout thread
     *
     * @param signCreationRequests <p>A pointer to the queue of sign creation requests</p>
     */
    public SignCreationRequestTimeoutThread(Queue<SignCreationRequest> signCreationRequests) {
        this.signCreationRequests = signCreationRequests;
    }

    @Override
    public void run() {
        long currentTime = System.currentTimeMillis();
        int requestTimeoutSeconds = 60;

        SignCreationRequest firstElement = signCreationRequests.peek();
        while (firstElement != null && currentTime > firstElement.initiationTime() + (1000 * requestTimeoutSeconds)) {
            //Remove any expired sign creation requests
            signCreationRequests.remove();
            firstElement = signCreationRequests.peek();
        }
    }

}
